#
# spec file for package miller
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           miller
Version:        5.3.0
Release:        lp152.3.6
Summary:        Name-indexed data processing tool
# c/lib/netbsd_strptime.c is BSD-4-Clause
License:        BSD-2-Clause and BSD-4-Clause
Group:          Productivity/File utilities
Url:            http://johnkerl.org/miller/doc
Source0:        https://github.com/johnkerl/miller/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM miller-5.3.0-gcc43.patch
Patch0:         miller-5.3.0-gcc43.patch
BuildRequires:  automake
BuildRequires:  flex >= 2.5.35
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Miller (mlr) allows name-indexed data such as CSV and JSON files to be
processed with functions equivalent to sed, awk, cut, join, sort etc. It can
convert between formats, preserves headers when sorting or reversing, and
streams data where possible so its memory requirements stay small. It works
well with pipes and can feed "tail -f".

%prep
%setup -q
%ifarch %ix86
sed -e 's/-pg//' -i c/Makefile.am
%endif
%patch0 -p1

%build
autoreconf -fiv
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc LICENSE.txt README.md c/draft-release-notes.md
%{_bindir}/mlr
%{_mandir}/man1/mlr.1%{ext_man}

%changelog
* Sun Jan  7 2018 aloisio@gmx.com
- Update to version 5.3.0 (see draft-release-notes.md for a
  changelog)
- Added miller-5.3.0-gcc43.patch
* Thu Aug 24 2017 aloisio@gmx.com
- Updated license
* Thu Jul 20 2017 aloisio@gmx.com
- Update to 5.2.2
  * This bugfix release delivers a fix for #147 where a memory
    allocation failed beyond 4GB.
* Tue Jun 20 2017 aloisio@gmx.com
- Update to version 5.2.1
  * Fixes (gh#johnkerl/miller#142) build segfault on non-x86
    architectures
* Tue Jun 13 2017 aloisio@gmx.com
- Update to version 5.2.0
  This release contains mostly feature requests.
  Features:
  * The stats1 verb now lets you use regular expressions to
    specify which field names to compute statistics on, and/or which
    to group by. Full details are here.
  * The min and max DSL functions, and the min/max/percentile
    aggregators for the stats1 and merge-fields verbs, now support
    numeric as well as string field values. (For mixed string/numeric
    fields, numbers compare before strings.) This means in particular
    that order statistics -- min, max, and non-interpolated
    percentiles -- as well as mode, antimode, and count are now
    possible on string-only fields. (Of course, any operations
    requiring arithmetic on values, such as computing sums, averages,
    or interpolated percentiles, yield an error on string-valued
    input.)
  * There is a new DSL function mapexcept which returns a copy of
    the argument with specified key(s), if any, unset. The motivating
    use-case is to split records to multiple filenames depending on
    particular field value, which is omitted from the output: mlr
  - -from f.dat put 'tee > "/tmp/data-".$a, mapexcept($*, "a")'
    Likewise, mapselect returns a copy of the argument with only
    specified key(s), if any, set. This resolves #137.
  * A new -u option for count-distinct allows unlashed counts for
    multiple field names. For example, with -f a,b and without -u,
    count-distinct computes counts for distinct pairs of a and b field
    values. With -f a,b and with -u, it computes counts for distinct a
    field values and counts for distinct b field values separately.
  * If you build from source, you can now do ./configure without
    first doing autoreconf -fiv. This resolves #131.
  * The UTF-8 BOM sequence 0xef 0xbb 0xbf is now automatically
    ignored from the start of CSV files. (The same is already done for
    JSON files.) This resolves #138.
  * For put and filter with -S, program literals such as the 6 in
    $x = 6 were being parsed as strings. This is not sensible, since
    the -S option for put and filter is intended to suppress numeric
    conversion of record data, not program literals. To get string 6
    one may use $x = "6".
  Documentation:
  * A new cookbook example shows how to compute differences
    between successive queries, e.g. to find out what changed in
    time-varying data when you run and rerun a SQL query.
  * Another new cookbook example shows how to compute
    interquartile ranges.
  * A third new cookbook example shows how to compute weighted
    means.
  Bugfixes:
  * CRLF line-endings were not being correctly autodetected when
    I/O formats were specified using --c2j et al.
  * Integer division by zero was causing a fatal runtime
    exception, rather than computing inf or nan as in the
    floating-point case.
* Sat Apr 15 2017 aloisio@gmx.com
- Update to 5.1.0 (see changelog at
  https://github.com/johnkerl/miller/releases/tag/v5.1.0)
* Sun Mar 12 2017 aloisio@gmx.com
- Update to version 5.0.1
  Minor bugfixes:
  * As described in #132, mlr nest was incorrectly splitting
    fields with multi-character separators.
  * The XTAB-format reader, when using multi-character IPS,
    was incorrectly splitting key-value pairs, but only when
    reading from standard input (e.g. on a pipe or less-than
    redirect).
* Tue Feb 28 2017 aloisio@gmx.com
- Initial package (v5.0.0)
